@@ -1,5 +1,7 @@
 from ._gaussian_detectors import LoGDetector, DoGDetector, DoHDetector
+from ._seg_detector import SSegDetector
 
 __all__ = ['LoGDetector',
            'DoGDetector',
-           'DoHDetector']
+           'DoHDetector',
+           'SSegDetector']
