@@ -1,11 +1,15 @@
-from ._reader_function import read_tracks
+from ._reader_function import read_tracks, write_tracks
 from ._csv_io import CSVIO
 from ._icy_io import ICYIO
 from ._isbi_io import ISBIIO
 from ._trackmate_io import TrackMateIO
 from ._st_io import StIO
+from ._particles_io import read_particles, write_particles
 
 __all__ = ['read_tracks',
+           'write_tracks',
+           'read_particles',
+           'write_particles',
            'StIO',
            'CSVIO',
            'ICYIO',
